SyllaPy
=======

[![PyPI version](https://badge.fury.io/py/syllapy.svg)](https://badge.fury.io/py/syllapy)

[![Build Status](https://travis-ci.org/mholtzscher/syllapy.svg?branch=master)](https://travis-ci.org/mholtzscher/syllapy)

Calculate syllable counts for English words.


Installation
------------

``` {.sourceCode .python}
pip install syllapy
```

Usage
-----

``` {.sourceCode .python}
import syllapy
count = syllapy.count('additional')
```

